==> about-2.0.0.tar.gz: CHANGELOG.md <==
# Changelog

## 2.0.0

- Opt-in null-safety
- Remove dependency on package_info

## 1.4.0
- Fix a bug with markdown tap handler being null introduced in 1.3.0
- Expose all Markdown properties

## 1.3.0

- Allow custom tap handlers for links in markdown pages
- Fix an error when leaving `license` page
- Update markdown dependency

## 1.2.0

- Add golden tests
- Add optional ScaffoldBuilder that can be used to provide a custom app scaffold around all pages

## 1.1.2

- Flutter_Markdown library 0.4.0 is somewhat invalid

## 1.1.1

- Update markdown library

## 1.1.0

- Fix showAboutPage as full-size page
- Use external mustache library
- Fix Cupertino dark theme

## 1.0.7

- Remove Localizations.override
- Update code style to Pedantic 1.9.0
- Reorganize the library
- Strip YAML header from Markdown files

## 1.0.6

- Prepare for 1.0.0 version of sensors and package_info. ([dart_lsc](https://github.com/amirh/dart_lsc))

## 1.0.5

- Remove builder, moved to pubspec_export
- Add more parameters
- Catch missing plugin exception
- Fix tests
- Fix license package names
- Add Android example
- Avoid too long subtitles
- Avoid copyright strings containing comments
- Remove useless values in licenses

## 1.0.4

- Fix dependencies

## 1.0.3

- Fix template issues with Flutter-web
- Add some space above of the icon
- Add an option to create a dialog

## 1.0.2

- Add missing properties on AboutPageListTile and showAboutPage
- Add unit tests
- Update README

## 1.0.1

- Add Cupertino style

## 1.0.0

- First version

==> about-2.0.1.tar.gz: CHANGELOG.md <==
# Changelog

## 2.0.1

- Fix Flutter-web support
- Improve Cupertino compatibility

## 2.0.0

- Opt-in null-safety
- Remove dependency on package_info

## 1.4.0

- Fix a bug with markdown tap handler being null introduced in 1.3.0
- Expose all Markdown properties

## 1.3.0

- Allow custom tap handlers for links in markdown pages
- Fix an error when leaving `license` page
- Update markdown dependency

## 1.2.0

- Add golden tests
- Add optional ScaffoldBuilder that can be used to provide a custom app scaffold around all pages

## 1.1.2

- Flutter_Markdown library 0.4.0 is somewhat invalid

## 1.1.1

- Update markdown library

## 1.1.0

- Fix showAboutPage as full-size page
- Use external mustache library
- Fix Cupertino dark theme

## 1.0.7

- Remove Localizations.override
- Update code style to Pedantic 1.9.0
- Reorganize the library
- Strip YAML header from Markdown files

## 1.0.6

- Prepare for 1.0.0 version of sensors and package_info. ([dart_lsc](https://github.com/amirh/dart_lsc))

## 1.0.5

- Remove builder, moved to pubspec_export
- Add more parameters
- Catch missing plugin exception
- Fix tests
- Fix license package names
- Add Android example
- Avoid too long subtitles
- Avoid copyright strings containing comments
- Remove useless values in licenses

## 1.0.4

- Fix dependencies

## 1.0.3

- Fix template issues with Flutter-web
- Add some space above the icon
- Add an option to create a dialog

## 1.0.2

- Add missing properties on AboutPageListTile and showAboutPage
- Add unit tests
- Update README

## 1.0.1

- Add Cupertino style

## 1.0.0

- First version
